
# EASY REST

Django easy rest is a rest framework with the focus of making development faster,
it is built on top of the awesome django rest framework (drf).

the main purpose of this framework is to give a speed boost to developers in rest api fields.

It features a rich and useful debugger, scripts, classes, mixins and brings django context to your javascripts

and does much more for you fore more read the docs:

[Read the docs](https://django-easy-rest.readthedocs.io/en/latest/)
